camelot.camelot.empty_project.settings

Package camelot :: Package camelot :: Package empty_project :: Module settings |
[hide private]
[frames] | no frames]

# Source Code for Module camelot.camelot.empty_project.settings

     1  import logging
     2  import inspect
     3  import camelot
     4  import os
     5

     6  logging.basicConfig(level=logging.ERROR)
     7

     8 -def setup_model():
     9    from model import *
    10    from camelot.model.memento import *
    11    from camelot.model.synchronization import *
    12    from camelot.model.authentication import *
    13    from camelot.model.i18n import *
    14    setup_all(create_tables=True)
    15    updateLastLogin()
    16

    17  CAMELOT_MAIN_DIRECTORY = os.path.dirname(inspect.getabsfile(camelot))
    18  CAMELOT_ART_DIRECTORY = os.path.join(CAMELOT_MAIN_DIRECTORY, 'art')
    19  CAMELOT_TEMPLATES_DIRECTORY = os.path.join(CAMELOT_MAIN_DIRECTORY,

    20                                             'view', 'templates')
    21  CAMELOT_ATTACHMENTS = ''
    22  CAMELOT_MEDIA_ROOT = ''
    23

    24  ENGINE = lambda:'sqlite:///model-data.sqlite'
    25